package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.core.web.domain.AjaxResult;
import java.util.List;
import com.ruoyi.system.api.model.LoginUser;
import com.ruoyi.common.core.utils.ServletUtils;
import com.ruoyi.system.domain.SnServerLog;
import com.ruoyi.common.security.service.TokenService;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.mapper.SnServerLogMapper;
import org.springframework.stereotype.Service;
import com.ruoyi.system.service.ISnServerLogService;

@Service
public class SnServerLogServiceImpl implements ISnServerLogService
{
    @Autowired
    private SnServerLogMapper snServerLogMapper;
    @Autowired
    private TokenService tokenService;
    
    public SnServerLog selectSnServerLogByLogId(final Long logId) {
        final SnServerLog obj = this.snServerLogMapper.selectSnServerLogByLogId(logId);
        if (obj == null || obj.getIsDelete().equals(1)) {
            return null;
        }
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        if (loginUser.getRoles().contains("admin") || loginUser.getRoles().contains("super")) {
            return obj;
        }
        if (loginUser.getRoles().contains("dealer")) {
            return obj.getDealerId().equals(loginUser.getUserid()) ? obj : null;
        }
        if (loginUser.getRoles().contains("agent")) {
            return obj.getAgentId().equals(loginUser.getUserid()) ? obj : null;
        }
        return obj.getCreateId().equals(loginUser.getUserid()) ? obj : null;
    }
    
    public List<SnServerLog> selectSnServerLogList(final SnServerLog obj) {
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        if (loginUser.getRoles().contains("dealer")) {
            obj.setDealerId(loginUser.getUserid());
        }
        if (loginUser.getRoles().contains("agent")) {
            obj.setAgentId(loginUser.getUserid());
        }
        if (loginUser.getRoles().contains("common")) {
            obj.setCreateId(loginUser.getUserid());
        }
        return this.snServerLogMapper.selectSnServerLogList(obj);
    }
    
    public AjaxResult insertSnServerLog(final SnServerLog snServerLog) {
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super") && !loginUser.getSysUser().getUserType().equals("common")) {
            return AjaxResult.error("暂无权限");
        }
        snServerLog.setCreateId(loginUser.getUserid());
        snServerLog.setCreateName(loginUser.getUsername());
        snServerLog.setAgentId(Long.valueOf(Long.parseLong(loginUser.getSysUser().getCreateBy())));
        snServerLog.setAgentName(loginUser.getSysUser().getCreateName());
        snServerLog.setIsDelete(Integer.valueOf(0));
        snServerLog.setCreateTime(DateUtils.getNowDate());
        snServerLog.setUpdateTime(DateUtils.getNowDate());
        return AjaxResult.success((Object)this.snServerLogMapper.insertSnServerLog(snServerLog));
    }
    
    public int updateSnServerLog(final SnServerLog snServerLog) {
        if (this.selectSnServerLogByLogId(snServerLog.getLogId()) == null) {
            return 0;
        }
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        snServerLog.setUpdateId(loginUser.getUserid());
        snServerLog.setUpdateName(loginUser.getUsername());
        snServerLog.setUpdateTime(DateUtils.getNowDate());
        snServerLog.setServerId((Long)null);
        snServerLog.setServerIp((String)null);
        snServerLog.setUpdateTime(DateUtils.getNowDate());
        return this.snServerLogMapper.updateSnServerLog(snServerLog);
    }
    
    public int deleteSnServerLogByLogIds(final Long[] logIds) {
        final LoginUser loginUser = this.tokenService.getLoginUser(ServletUtils.getRequest());
        Long createId = null;
        if (!loginUser.getRoles().contains("admin") && !loginUser.getRoles().contains("super")) {
            createId = loginUser.getUserid();
            return this.snServerLogMapper.deleteSnServerLogByLogIdsV2(logIds, createId);
        }
        return this.snServerLogMapper.deleteSnServerLogByLogIds(logIds);
    }
    
    public int deleteSnServerLogByLogId(final Long logId) {
        return this.snServerLogMapper.deleteSnServerLogByLogId(logId);
    }
}
